@@ -1,40 +1,21 @@
 /*
-   Copyright (c) 2012-2015 Vishesh Handa <me@vhanda.in>
+    SPDX-FileCopyrightText: 2012-2015 Vishesh Handa <me@vhanda.in>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include <QCoreApplication>
-#include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QFile>
 
 #include <KAboutData>
-#include <KConfig>
-#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KFormat>
-#include <QStandardPaths>
 #include <QProcess>
 #include <QTextStream>
 #include <QFileInfo>
 #include <QLocale>
 
-#include <QDBusMessage>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 
@@ -42,6 +23,7 @@
 #include "database.h"
 #include "transaction.h"
 #include "databasesize.h"
+#include "config.h"
 
 #include "indexer.h"
 #include "indexerconfig.h"
@@ -58,16 +40,16 @@ using namespace Baloo;
 
 void start()
 {
-    const QString exe = QStandardPaths::findExecutable(QStringLiteral("baloo_file"));
-    QProcess::startDetached(exe);
+    const QString exe = QStringLiteral(KDE_INSTALL_FULL_LIBEXECDIR_KF "/baloo_file");
+    QProcess::startDetached(exe, QStringList());
 }
 
 int main(int argc, char* argv[])
 {
     QCoreApplication app(argc, argv);
 
-    KAboutData aboutData(QStringLiteral("baloo"), i18n("balooctl"), PROJECT_VERSION);
-    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), QStringLiteral("vhanda@kde.org"));
+    KAboutData aboutData(QStringLiteral("baloo"), i18n("balooctl"), QStringLiteral(PROJECT_VERSION));
+    aboutData.addAuthor(i18n("Vishesh Handa"), QString(), QStringLiteral("vhanda@kde.org"));
 
     KAboutData::setApplicationData(aboutData);
 
@@ -105,7 +87,6 @@ int main(int argc, char* argv[])
         parser.showHelp(1);
     }
 
-    QTextStream err(stderr);
     QTextStream out(stdout);
 
     QString command = parser.positionalArguments().first();
@@ -118,14 +99,14 @@ int main(int argc, char* argv[])
                                         QStringLiteral("/scheduler"),
                                         QDBusConnection::sessionBus());
 
-    if (command == QStringLiteral("config")) {
+    if (command == QLatin1String("config")) {
         ConfigCommand command;
         return command.exec(parser);
     }
 
     if (command == QLatin1String("status")) {
-        StatusCommand command;
-        return command.exec(parser);
+        StatusCommand commandStatus;
+        return commandStatus.exec(parser);
     }
 
     if (command == QLatin1String("enable") || command == QLatin1String("disable")) {
@@ -168,7 +149,7 @@ int main(int argc, char* argv[])
                 if (!mainInterface.isValid()) {
                     break;
                 }
-                out << "." << flush;
+                out << "." << Qt::flush;
                 QThread::msleep(200);
             }
             if (!mainInterface.isValid()) {
@@ -191,25 +172,25 @@ int main(int argc, char* argv[])
         return 0;
     }
 
-    if (command == QStringLiteral("suspend")) {
+    if (command == QLatin1String("suspend")) {
         schedulerinterface.suspend();
         out << "File Indexer suspended\n";
         return 0;
     }
 
-    if (command == QStringLiteral("resume")) {
+    if (command == QLatin1String("resume")) {
         schedulerinterface.resume();
         out << "File Indexer resumed\n";
         return 0;
     }
 
-    if (command == QStringLiteral("check")) {
+    if (command == QLatin1String("check")) {
         schedulerinterface.checkUnindexedFiles();
         out << "Started search for unindexed files\n";
         return 0;
     }
 
-    if (command == QStringLiteral("index")) {
+    if (command == QLatin1String("index")) {
         if (parser.positionalArguments().size() < 2) {
             out << "Please enter a filename to index\n";
             return 1;
@@ -227,7 +208,7 @@ int main(int argc, char* argv[])
             const QString url = QFileInfo(parser.positionalArguments().at(i)).absoluteFilePath();
             quint64 id = filePathToId(QFile::encodeName(url));
             if (id == 0) {
-                out << "Could not stat file: " << url << endl;
+                out << "Could not stat file: " << url << '\n';
                 continue;
             }
             if (tr.inPhaseOne(id))  {
@@ -239,7 +220,7 @@ int main(int argc, char* argv[])
                 continue;
             }
             Indexer indexer(url, &tr);
-            out << "Indexing " << url << endl;
+            out << "Indexing " << url << '\n';
             indexer.index();
         }
         tr.commit();
@@ -248,7 +229,7 @@ int main(int argc, char* argv[])
         return 0;
     }
 
-    if (command == QStringLiteral("clear")) {
+    if (command == QLatin1String("clear")) {
         if (parser.positionalArguments().size() < 2) {
             out << "Please enter a filename to index\n";
             return 1;
@@ -266,10 +247,17 @@ int main(int argc, char* argv[])
             const QString url = QFileInfo(parser.positionalArguments().at(i)).absoluteFilePath();
             quint64 id = filePathToId(QFile::encodeName(url));
             if (id == 0) {
-                out << "Could not stat file: " << url << endl;
-                continue;
+                id = tr.documentId(QFile::encodeName(url));
+                if (id == 0) {
+                    out << "File not found on filesystem or in DB: " << url << '\n';
+                    continue;
+                } else {
+                    out << "File has been deleted, clearing from DB: " << url << '\n';
+                }
+            } else {
+                out << "Clearing " << url << '\n';
             }
-            out << "Clearing " << url << endl;
+
             tr.removeDocument(id);
         }
         tr.commit();
@@ -278,7 +266,7 @@ int main(int argc, char* argv[])
         return 0;
     }
 
-    if (command == QStringLiteral("failed")) {
+    if (command == QLatin1String("failed")) {
         Database *db = globalDatabaseInstance();
         if (!db->open(Database::ReadOnlyDatabase)) {
             out << "Baloo Index could not be opened\n";
@@ -294,7 +282,7 @@ int main(int argc, char* argv[])
             return 0;
         }
 
-        out << "The folling files could not be indexed:\n";
+        out << "The following files could not be indexed:\n";
         for (auto id : failedIds) {
             out << tr.documentUrl(id) << '\n';
         }
@@ -304,7 +292,7 @@ int main(int argc, char* argv[])
         return 0;
     }
 
-    if (command == QStringLiteral("indexSize")) {
+    if (command == QLatin1String("indexSize")) {
         Database *db = globalDatabaseInstance();
         if (!db->open(Database::ReadOnlyDatabase)) {
             out << "Baloo Index could not be opened\n";
@@ -350,14 +338,14 @@ int main(int argc, char* argv[])
         return 0;
     }
 
-    if (command == QStringLiteral("monitor")) {
+    if (command == QLatin1String("monitor")) {
         MonitorCommand mon;
         return mon.exec(parser);
     }
 
     /*
      TODO: Make separate executable
-     if (command == QStringLiteral("checkDb")) {
+     if (command == QLatin1String("checkDb")) {
         Database *db = globalDatabaseInstance();
         if (!db->open(Database::ReadOnlyDatabase)) {
             out << "Baloo Index could not be opened\n";
@@ -367,7 +355,7 @@ int main(int argc, char* argv[])
         Transaction tr(db, Transaction::ReadOnly);
         tr.checkPostingDbinTermsDb();
         tr.checkTermsDbinPostingDb();
-        out << "Checking file paths .. " << endl;
+        out << "Checking file paths .. "<< '\n';
         tr.checkFsTree();
         return 0;
     }
